@@ -1,12 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "evil-collection" "0.0.10"
+(define-package "evil-collection" "20251024.2337"
   "A set of keybindings for Evil mode."
   '((emacs    "26.3")
     (evil     "1.2.13")
     (annalist "1.0"))
   :url "https://github.com/emacs-evil/evil-collection"
-  :commit "d0518fc1626f09a341d4b5a98c857087abfb1b0c"
-  :revdesc "d0518fc1626f"
+  :commit "092408dcf7655c299d69b8cacb85bdea59598196"
+  :revdesc "092408dcf765"
   :keywords '("evil" "tools")
   :authors '(("James Nguyen" . "james@jojojames.com"))
   :maintainers '(("James Nguyen" . "james@jojojames.com")))
