@@ -7,8 +7,8 @@
 ;; Maintainer: James Nguyen <james@jojojames.com>
 ;; Pierre Neidhardt <mail@ambrevar.xyz>
 ;; URL: https://github.com/emacs-evil/evil-collection
-;; Package-Version: 0.0.10
-;; Package-Revision: d0518fc1626f
+;; Package-Version: 20251024.2337
+;; Package-Revision: 092408dcf765
 ;; Package-Requires: ((emacs "26.3") (evil "1.2.13") (annalist "1.0"))
 ;; Keywords: evil, tools
 
@@ -160,6 +160,7 @@ See `evil-collection-init' and `evil-collection--modes-with-delayed-setup'."
     calc
     calendar
     cider
+    citre
     cmake-mode
     color-rg
     comint
@@ -168,8 +169,10 @@ See `evil-collection-init' and `evil-collection--modes-with-delayed-setup'."
     consult
     corfu
     crdt
+    (csv "csv-mode")
     (custom cus-edit)
     cus-theme
+    dape
     dashboard
     daemons
     deadgrep
@@ -179,12 +182,14 @@ See `evil-collection-init' and `evil-collection--modes-with-delayed-setup'."
     dictionary
     diff-hl
     diff-mode
+    difftastic
     dired
     dired-sidebar
     disk-usage
     distel
     doc-view
     docker
+    eat
     ebib
     ebuku
     edbi
@@ -220,6 +225,7 @@ See `evil-collection-init' and `evil-collection--modes-with-delayed-setup'."
     gited
     gnus
     go-mode
+    gptel
     grep
     guix
     hackernews
@@ -227,7 +233,9 @@ See `evil-collection-init' and `evil-collection--modes-with-delayed-setup'."
     help
     helpful
     hg-histedit
+    hideshow
     hungry-delete
+    hyrolo
     ibuffer
     (image image-mode)
     image-dired
@@ -239,6 +247,7 @@ See `evil-collection-init' and `evil-collection--modes-with-delayed-setup'."
     info
     ivy
     js2-mode
+    ,@(when (>= emacs-major-version 30) '(kmacro))
     leetcode
     lispy
     lms
@@ -249,14 +258,17 @@ See `evil-collection-init' and `evil-collection--modes-with-delayed-setup'."
     kotlin-mode
     macrostep
     man
-    (magit magit-repos magit-submodule)
+    (magit magit-submodule) ;; See https://github.com/emacs-evil/evil-collection/issues/637
+    magit-repos
     magit-section
     magit-todos
     markdown-mode
+    minesweeper
     ,@(when evil-collection-setup-minibuffer '(minibuffer))
     monky
     mpc
     mpdel
+    mpdired
     mu4e
     mu4e-conversation
     neotree
@@ -269,6 +281,7 @@ See `evil-collection-init' and `evil-collection--modes-with-delayed-setup'."
     org-roam
     osx-dictionary
     outline
+    ovpn-mode
     p4
     (package-menu package)
     pass
@@ -278,10 +291,12 @@ See `evil-collection-init' and `evil-collection--modes-with-delayed-setup'."
     (process-menu simple)
     prodigy
     profiler
+    p-search
     python
     quickrun
     racer
     racket-describe
+    reader
     realgud
     reftex
     replace ;; For `occur'.
@@ -301,6 +316,7 @@ See `evil-collection-init' and `evil-collection--modes-with-delayed-setup'."
     simple-mpc
     slime
     sly
+    smerge-mode
     snake
     so-long
     speedbar
@@ -318,6 +334,7 @@ See `evil-collection-init' and `evil-collection--modes-with-delayed-setup'."
     trashed
     tuareg
     typescript-mode
+    ultra-scroll
     vc-annotate
     vc-dir
     vc-git
@@ -331,6 +348,7 @@ See `evil-collection-init' and `evil-collection--modes-with-delayed-setup'."
     wdired
     wgrep
     which-key
+    with-editor
     woman
     xref
     xwidget
@@ -684,7 +702,8 @@ NAME specifies the name of the entry added to HOOK.  If APPEND is
 non-nil, the entry is appended to the hook.  If LOCAL is non-nil,
 the buffer-local value of HOOK is modified.
 
-This is a backport of `evil-delay' without the deprecation notice to deal with CI until migration can be done.
+This is a backport of `evil-delay' without the deprecation notice to deal with
+CI until migration can be done.
 Ref: https://github.com/emacs-evil/evil-collection/issues/750"
   (eval `(evil-with-delay ,condition (,hook ,append ,local ,name) ,form) t))
 
@@ -721,7 +740,7 @@ invocation."
       (dolist (state states)
         (let ((hook-name
                (symbol-name
-                (cl-gensym
+                (gensym
                  (format "evil-collection-translate-key-in-%s" keymap-symbol)))))
           (evil-collection--delay `(and (boundp ',keymap-symbol)
                                        (keymapp ,keymap-symbol))
@@ -832,7 +851,7 @@ invocation."
     (dolist (state states)
       (let ((hook-name
              (symbol-name
-              (cl-gensym
+              (gensym
                (format "evil-collection-translate-key-in-%s" keymap-symbol)))))
         (evil-collection--delay `(and (boundp ',keymap-symbol)
                                       (keymapp ,keymap-symbol))
